pub struct CommandAllocatePrimaryAction {
pub index: String,
pub node: String,
pub accept_data_loss: bool,
pub shard: u32,
}Fields
index: Stringnode: Stringaccept_data_loss: boolIf a node which has a copy of the data rejoins the cluster later on, that data will be deleted. To ensure that these implications are well-understood, this command requires the flag accept_data_loss to be explicitly set to true.
shard: u32Implementations