pub struct ClusterOperatingSystem {
pub architectures: Option<Vec<ClusterOperatingSystemArchitecture>>,
pub pretty_names: Vec<ClusterOperatingSystemPrettyName>,
pub allocated_processors: u32,
pub names: Vec<ClusterOperatingSystemName>,
pub available_processors: u32,
pub mem: OperatingSystemMemoryInfo,
}Fields
architectures: Option<Vec<ClusterOperatingSystemArchitecture>>Contains statistics about processor architectures (for example, x86_64 or aarch64) used by selected nodes.
pretty_names: Vec<ClusterOperatingSystemPrettyName>Contains statistics about operating systems used by selected nodes.
allocated_processors: u32Number of processors used to calculate thread pool size across all selected nodes. This number can be set with the processors setting of a node and defaults to the number of processors reported by the operating system. In both cases, this number will never be larger than 32.
names: Vec<ClusterOperatingSystemName>Contains statistics about operating systems used by selected nodes.
available_processors: u32Number of processors available to JVM across all selected nodes.
mem: OperatingSystemMemoryInfoImplementations
Sourceimpl ClusterOperatingSystem
impl ClusterOperatingSystem
pub fn new( pretty_names: Vec<ClusterOperatingSystemPrettyName>, allocated_processors: u32, names: Vec<ClusterOperatingSystemName>, available_processors: u32, mem: OperatingSystemMemoryInfo, ) -> ClusterOperatingSystem