pub struct PutComponentTemplate {
pub allow_auto_create: Option<bool>,
pub template: IndexState,
pub version: Option<u32>,
pub meta: Option<Metadata>,
}Expand description
PutComponentTemplate The template definition.
Fields
allow_auto_create: Option<bool>This setting overrides the action.auto_create_index cluster setting.
When set to true in a component template, indexes are automatically created using that
template. When set to false, data streams matching the component template must always be explicitly created.
template: IndexStateversion: Option<u32>meta: Option<Metadata>Implementations
Sourceimpl PutComponentTemplate
impl PutComponentTemplate
Sourcepub fn new(template: IndexState) -> PutComponentTemplate
pub fn new(template: IndexState) -> PutComponentTemplate
The template definition.