pub struct PutComponentTemplateRequestBodyJson {
pub version: Option<u32>,
pub meta: Option<Metadata>,
pub allow_auto_create: Option<bool>,
pub template: IndexState,
}Expand description
PutComponentTemplateRequestBodyJson The template definition.
Fields
version: Option<u32>meta: Option<Metadata>allow_auto_create: Option<bool>This setting overrides the action.auto_create_index cluster setting.
When set to true in a component template, indexes are automatically created using that
template. When set to false, data streams matching the component template must always be explicitly created.
template: IndexStateImplementations
Sourceimpl PutComponentTemplateRequestBodyJson
impl PutComponentTemplateRequestBodyJson
Sourcepub fn new(template: IndexState) -> PutComponentTemplateRequestBodyJson
pub fn new(template: IndexState) -> PutComponentTemplateRequestBodyJson
The template definition.