pub enum BucketsQueryContainer {
ArrayValue(Vec<Value>),
KeyedValue(Value),
}Expand description
BucketsQueryContainer Aggregation buckets. By default they are returned as an array, but if the aggregation has keys configured for the different buckets, the result is a dictionary.
Variants