pub struct ClassificationInferenceOptions {
pub num_top_classes: Option<u32>,
pub num_top_feature_importance_values: Option<u32>,
pub results_field: Option<String>,
pub top_classes_results_field: Option<String>,
pub prediction_field_type: Option<String>,
}Fields
num_top_classes: Option<u32>Specifies the number of top class predictions to return. Defaults to 0.
num_top_feature_importance_values: Option<u32>Specifies the maximum number of feature importance values per document.
results_field: Option<String>The field that is added to incoming documents to contain the inference prediction. Defaults to predicted_value.
top_classes_results_field: Option<String>Specifies the field to which the top classes are written. Defaults to top_classes.
prediction_field_type: Option<String>Specifies the type of the predicted field to write. Acceptable values are: string, number, Boolean. When Boolean is provided 1.0 is transformed to true and 0.0 to false.
Implementations