pub struct DateRangeExpression {
pub from: Option<FieldDateMath>,
pub key: Option<String>,
pub to: Option<FieldDateMath>,
}Fields
from: Option<FieldDateMath>A date range limit, represented either as a DateMath expression or a number expressed according to the target field’s precision.
key: Option<String>Custom key to return the range with.
to: Option<FieldDateMath>A date range limit, represented either as a DateMath expression or a number expressed according to the target field’s precision.
Implementations
Sourceimpl DateRangeExpression
impl DateRangeExpression
pub fn new() -> DateRangeExpression