pub struct MatrixStatsFields {
pub skewness: f64,
pub name: String,
pub correlation: Value,
pub count: f64,
pub variance: f64,
pub kurtosis: f64,
pub mean: f64,
pub covariance: Value,
}Fields
skewness: f64name: StringThe path to a field or an array of paths. Some APIs support wildcards in the path, which allows you to select multiple fields.
correlation: Valuecount: f64variance: f64kurtosis: f64mean: f64covariance: ValueImplementations