pub struct VariableWidthHistogramAggregation {
pub initial_buffer: Option<u32>,
pub shard_size: Option<u32>,
pub field: Option<String>,
pub buckets: Option<u32>,
}Fields
initial_buffer: Option<u32>Specifies the number of individual documents that will be stored in memory on a shard before the initial bucketing algorithm is run.
Defaults to min(10 * shard_size, 50000).
shard_size: Option<u32>The number of buckets that the coordinating node will request from each shard.
Defaults to buckets * 50.
field: Option<String>The path to a field or an array of paths. Some APIs support wildcards in the path, which allows you to select multiple fields.
buckets: Option<u32>The target number of buckets.
Implementations