pub struct BulkByScrollTaskStatus {Show 16 fields
pub requests_per_second: f64,
pub total: u32,
pub deleted: u32,
pub updated: Option<u32>,
pub created: Option<u32>,
pub retries: Retries,
pub version_conflicts: u32,
pub canceled: Option<String>,
pub throttled_millis: String,
pub throttled_until_millis: String,
pub throttled: Option<String>,
pub batches: u32,
pub noops: u32,
pub slice_id: Option<u32>,
pub slices: Option<Vec<BulkByScrollTaskStatusOrException>>,
pub throttled_until: Option<String>,
}Fields
requests_per_second: f64The number of requests per second effectively executed during the reindex operation.
total: u32The number of documents that were successfully processed.
deleted: u32The number of documents that were successfully deleted.
updated: Option<u32>The number of documents that were successfully updated after the reindex operation.
created: Option<u32>The number of documents that were successfully created.
retries: Retriesversion_conflicts: u32The number of version conflicts encountered by the reindex operation.
canceled: Option<String>throttled_millis: Stringthrottled_until_millis: Stringthrottled: Option<String>A duration. Units can be nanos, micros, ms (milliseconds), s (seconds), m (minutes), h (hours) and
d (days). Also accepts “0” without a unit and “-1” to indicate an unspecified value.
batches: u32The number of scroll responses pulled back by the reindex operation.
noops: u32The number of documents that were ignored.
slice_id: Option<u32>slices: Option<Vec<BulkByScrollTaskStatusOrException>>throttled_until: Option<String>A duration. Units can be nanos, micros, ms (milliseconds), s (seconds), m (minutes), h (hours) and
d (days). Also accepts “0” without a unit and “-1” to indicate an unspecified value.
Implementations