pub struct ClearScroll {
pub scroll_id: Option<ScrollIds>,
}Expand description
ClearScroll
Comma-separated list of scroll IDs to clear if none was specified using the scroll_id parameter
Fields
scroll_id: Option<ScrollIds>Implementations
Sourceimpl ClearScroll
impl ClearScroll
Sourcepub fn new() -> ClearScroll
pub fn new() -> ClearScroll
Comma-separated list of scroll IDs to clear if none was specified using the scroll_id parameter