DocStats

Struct DocStats 

pub struct DocStats {
    pub count: u32,
    pub deleted: Option<u32>,
}

Fields

count: u32

The total number of non-deleted documents across all primary shards assigned to the selected nodes. This number is based on documents in Lucene segments and may include documents from nested fields.

deleted: Option<u32>

The total number of deleted documents across all primary shards assigned to the selected nodes. This number is based on the number of documents stored in Lucene segments. OpenSearch reclaims the disk space previously occupied by the deleted Lucene documents when a segment is merged.

Implementations

Source

impl DocStats

pub fn new(count: u32) -> DocStats