pub struct NestedSortValue {
pub max_children: Option<u32>,
pub filter: Option<Query>,
pub path: String,
pub nested: Option<Box<NestedSortValue>>,
}Fields
max_children: Option<u32>filter: Option<Query>path: StringThe path to a field or an array of paths. Some APIs support wildcards in the path, which allows you to select multiple fields.
nested: Option<Box<NestedSortValue>>Implementations
Sourceimpl NestedSortValue
impl NestedSortValue
pub fn new(path: String) -> NestedSortValue