pub struct NodeStatistics {
pub failures: Option<Vec<ErrorCause>>,
pub successful: u32,
pub total: u32,
pub failed: u32,
}Fields
failures: Option<Vec<ErrorCause>>successful: u32The number of nodes that responded successfully to the request.
total: u32The total number of nodes selected by the request.
failed: u32The number of nodes that rejected the request or failed to respond. If this value is not 0, then a reason for the rejection or failure is included in the response.
Implementations