pub struct QueryCacheStats {
pub total_count: u32,
pub cache_size: u32,
pub memory_size: Option<String>,
pub hit_count: u32,
pub cache_count: u32,
pub miss_count: u32,
pub evictions: u32,
pub memory_size_in_bytes: u32,
}Fields
total_count: u32The total number of hits and misses stored in the query cache across all shards assigned to the selected nodes.
cache_size: u32The total number of entries currently stored in the query cache across all shards assigned to the selected nodes.
memory_size: Option<String>hit_count: u32The total number of query cache hits across all shards assigned to the selected nodes.
cache_count: u32The total number of entries added to the query cache across all shards assigned to the selected nodes. This number includes all current and evicted entries.
miss_count: u32The total number of query cache misses across all shards assigned to the selected nodes.
evictions: u32The total number of query cache evictions across all shards assigned to the selected nodes.
memory_size_in_bytes: u32Implementations