pub struct QueryBase {
pub boost: Option<f64>,
pub name: Option<String>,
}Fields
boost: Option<f64>Floating point number used to decrease or increase the relevance scores of the query. Boost values are relative to the default value of 1.0. A boost value between 0 and 1.0 decreases the relevance score. A value greater than 1.0 increases the relevance score.
name: Option<String>Implementations