QueryContainer

Struct QueryContainer 

pub struct QueryContainer {
Show 56 fields pub nested: Option<String>, pub parent_id: Option<String>, pub field_masking_span: Option<String>, pub match_phrase: Option<Value>, pub intervals: Option<Value>, pub boosting: Option<String>, pub percolate: Option<String>, pub span_near: Option<String>, pub span_not: Option<String>, pub geo_bounding_box: Option<String>, pub match_bool_prefix: Option<Value>, pub prefix: Option<Value>, pub more_like_this: Option<String>, pub span_multi: Option<String>, pub common: Option<Value>, pub span_within: Option<String>, pub ids: Option<String>, pub distance_feature: Option<String>, pub geo_polygon: Option<String>, pub match_all: Option<String>, pub range: Option<Value>, pub combined_fields: Option<String>, pub fuzzy: Option<Value>, pub match_phrase_prefix: Option<Value>, pub function_score: Option<String>, pub geo_shape: Option<String>, pub constant_score: Option<String>, pub hybrid: Option<String>, pub multi_match: Option<String>, pub pinned: Option<String>, pub rank_feature: Option<String>, pub neural: Option<Value>, pub script: Option<String>, pub script_score: Option<String>, pub has_parent: Option<String>, pub geo_distance: Option<String>, pub span_containing: Option<String>, pub regexp: Option<Value>, pub span_term: Option<Value>, pub terms: Option<String>, pub wildcard: Option<Value>, pub wrapper: Option<String>, pub exists: Option<String>, pub simple_query_string: Option<String>, pub type: Option<String>, pub term: Option<Value>, pub match_none: Option<String>, pub query_string: Option<String>, pub dis_max: Option<String>, pub span_first: Option<String>, pub span_or: Option<String>, pub has_child: Option<String>, pub terms_set: Option<Value>, pub knn: Option<Value>, pub match: Option<Value>, pub bool: Option<String>,
}

Fields

nested: Option<String>parent_id: Option<String>field_masking_span: Option<String>match_phrase: Option<Value>

Analyzes the text and creates a phrase query out of the analyzed text.

intervals: Option<Value>

Returns documents based on the order and proximity of matching terms.

boosting: Option<String>percolate: Option<String>span_near: Option<String>span_not: Option<String>geo_bounding_box: Option<String>match_bool_prefix: Option<Value>

Analyzes its input and constructs a bool query from the terms. Each term except the last is used in a term query. The last term is used in a prefix query.

prefix: Option<Value>

Returns documents that contain a specific prefix in a provided field.

more_like_this: Option<String>span_multi: Option<String>common: Option<Value>span_within: Option<String>ids: Option<String>distance_feature: Option<String>geo_polygon: Option<String>match_all: Option<String>range: Option<Value>

Returns documents that contain terms within a provided range.

combined_fields: Option<String>fuzzy: Option<Value>

Returns documents that contain terms similar to the search term, as measured by a Levenshtein edit distance.

match_phrase_prefix: Option<Value>

Returns documents that contain the words of a provided text, in the same order as provided. The last term of the provided text is treated as a prefix, matching any words that begin with that term.

function_score: Option<String>geo_shape: Option<String>constant_score: Option<String>hybrid: Option<String>multi_match: Option<String>pinned: Option<String>rank_feature: Option<String>neural: Option<Value>script: Option<String>script_score: Option<String>has_parent: Option<String>geo_distance: Option<String>span_containing: Option<String>regexp: Option<Value>

Returns documents that contain terms matching a regular expression.

span_term: Option<Value>

Matches spans containing a term.

terms: Option<String>wildcard: Option<Value>

Returns documents that contain terms matching a wildcard pattern.

wrapper: Option<String>exists: Option<String>simple_query_string: Option<String>type: Option<String>term: Option<Value>

Returns documents that contain an exact term in a provided field. To return a document, the query term must exactly match the queried field’s value, including white space and capitalization.

match_none: Option<String>query_string: Option<String>dis_max: Option<String>span_first: Option<String>span_or: Option<String>has_child: Option<String>terms_set: Option<Value>

Returns documents that contain a minimum number of exact terms in a provided field. To return a document, a required number of terms must exactly match the field values, including white space and capitalization.

knn: Option<Value>match: Option<Value>

Returns documents that match a provided text, number, date or Boolean value. The provided text is analyzed before matching.

bool: Option<String>

Implementations