pub struct SpanGapQuery {}Expand description
SpanGapQuery
Can only be used as a clause in a span_near query.
Implementations
Sourceimpl SpanGapQuery
impl SpanGapQuery
Sourcepub fn new() -> SpanGapQuery
pub fn new() -> SpanGapQuery
Can only be used as a clause in a span_near query.