pub struct SpanQuery {
pub span_or: Option<String>,
pub span_within: Option<String>,
pub span_not: Option<String>,
pub span_multi: Option<String>,
pub span_first: Option<String>,
pub field_masking_span: Option<String>,
pub span_gap: Option<SpanGapQuery>,
pub span_containing: Option<String>,
pub span_term: Option<Value>,
pub span_near: Option<String>,
}Fields
span_or: Option<String>span_within: Option<String>span_not: Option<String>span_multi: Option<String>span_first: Option<String>field_masking_span: Option<String>span_gap: Option<SpanGapQuery>Can only be used as a clause in a span_near query.
span_containing: Option<String>span_term: Option<Value>The equivalent of the term query but for use with other span queries.
span_near: Option<String>Implementations