pub struct RemoteStoreStats {
pub upload: RemoteStoreUploadStats,
pub download: RemoteStoreDownloadStats,
}Expand description
RemoteStoreStats Statistics related to remote segment store operations.
Fields
upload: RemoteStoreUploadStatsStatistics related to uploads to the remote segment store.
download: RemoteStoreDownloadStatsStatistics related to downloads to the remote segment store.
Implementations
Sourceimpl RemoteStoreStats
impl RemoteStoreStats
Sourcepub fn new(
upload: RemoteStoreUploadStats,
download: RemoteStoreDownloadStats,
) -> RemoteStoreStats
pub fn new( upload: RemoteStoreUploadStats, download: RemoteStoreDownloadStats, ) -> RemoteStoreStats
Statistics related to remote segment store operations.