pub struct RemoteStoreTranslogUploadStats {
pub total_upload_size: RemoteStoreTranslogUploadTotalUploadSizeStats,
pub total_uploads: RemoteStoreTranslogUploadTotalUploadsStats,
}Expand description
RemoteStoreTranslogUploadStats Statistics related to uploads to the remote translog store.
Fields
total_upload_size: RemoteStoreTranslogUploadTotalUploadSizeStatsThe total amount of data uploaded to the remote translog store.
total_uploads: RemoteStoreTranslogUploadTotalUploadsStatsThe number of syncs to the remote translog store.
Implementations
Sourceimpl RemoteStoreTranslogUploadStats
impl RemoteStoreTranslogUploadStats
Sourcepub fn new(
total_upload_size: RemoteStoreTranslogUploadTotalUploadSizeStats,
total_uploads: RemoteStoreTranslogUploadTotalUploadsStats,
) -> RemoteStoreTranslogUploadStats
pub fn new( total_upload_size: RemoteStoreTranslogUploadTotalUploadSizeStats, total_uploads: RemoteStoreTranslogUploadTotalUploadsStats, ) -> RemoteStoreTranslogUploadStats
Statistics related to uploads to the remote translog store.