pub struct RemoteStoreUploadStats {
pub total_time_spent: Option<String>,
pub max_refresh_time_lag: Option<String>,
pub total_time_spent_in_millis: String,
pub total_upload_size: RemoteStoreUploadDownloadStats,
pub pressure: Option<RemoteStoreUploadPressureStats>,
pub refresh_size_lag: RemoteStoreUploadRefreshSizeLagStats,
pub max_refresh_time_lag_in_millis: String,
}Expand description
RemoteStoreUploadStats Statistics related to uploads to the remote segment store.
Fields
total_time_spent: Option<String>A duration. Units can be nanos, micros, ms (milliseconds), s (seconds), m (minutes), h (hours) and
d (days). Also accepts “0” without a unit and “-1” to indicate an unspecified value.
max_refresh_time_lag: Option<String>A duration. Units can be nanos, micros, ms (milliseconds), s (seconds), m (minutes), h (hours) and
d (days). Also accepts “0” without a unit and “-1” to indicate an unspecified value.
total_time_spent_in_millis: Stringtotal_upload_size: RemoteStoreUploadDownloadStatsThe amount of data, in bytes, uploaded or downloaded to/from the remote segment store.
pressure: Option<RemoteStoreUploadPressureStats>Statistics related to segment store upload backpressure.
refresh_size_lag: RemoteStoreUploadRefreshSizeLagStatsThe amount of lag during upload between the remote segment store and the local store.
max_refresh_time_lag_in_millis: StringImplementations
Sourceimpl RemoteStoreUploadStats
impl RemoteStoreUploadStats
Sourcepub fn new(
total_time_spent_in_millis: String,
total_upload_size: RemoteStoreUploadDownloadStats,
refresh_size_lag: RemoteStoreUploadRefreshSizeLagStats,
max_refresh_time_lag_in_millis: String,
) -> RemoteStoreUploadStats
pub fn new( total_time_spent_in_millis: String, total_upload_size: RemoteStoreUploadDownloadStats, refresh_size_lag: RemoteStoreUploadRefreshSizeLagStats, max_refresh_time_lag_in_millis: String, ) -> RemoteStoreUploadStats
Statistics related to uploads to the remote segment store.