pub struct SegmentsStats {Show 25 fields
pub remote_store: Option<RemoteStoreStats>,
pub stored_fields_memory_in_bytes: u32,
pub terms_memory: Option<String>,
pub terms_memory_in_bytes: u32,
pub norms_memory: Option<String>,
pub term_vectors_memory: Option<String>,
pub term_vectors_memory_in_bytes: u32,
pub doc_values_memory_in_bytes: u32,
pub version_map_memory: Option<String>,
pub count: u32,
pub stored_fields_memory: Option<String>,
pub index_writer_memory_in_bytes: u32,
pub index_writer_memory: Option<String>,
pub index_writer_max_memory_in_bytes: Option<u32>,
pub memory_in_bytes: u32,
pub fixed_bit_set_memory_in_bytes: u32,
pub doc_values_memory: Option<String>,
pub file_sizes: Value,
pub fixed_bit_set: Option<String>,
pub max_unsafe_auto_id_timestamp: String,
pub memory: Option<String>,
pub norms_memory_in_bytes: u32,
pub points_memory_in_bytes: u32,
pub version_map_memory_in_bytes: u32,
pub points_memory: Option<String>,
}Fields
remote_store: Option<RemoteStoreStats>Statistics related to remote segment store operations.
stored_fields_memory_in_bytes: u32terms_memory: Option<String>terms_memory_in_bytes: u32norms_memory: Option<String>term_vectors_memory: Option<String>term_vectors_memory_in_bytes: u32doc_values_memory_in_bytes: u32version_map_memory: Option<String>count: u32The total number of segments across all shards assigned to the selected nodes.
stored_fields_memory: Option<String>index_writer_memory_in_bytes: u32index_writer_memory: Option<String>index_writer_max_memory_in_bytes: Option<u32>memory_in_bytes: u32fixed_bit_set_memory_in_bytes: u32doc_values_memory: Option<String>file_sizes: ValueThis object is not populated by the cluster stats API. To get information on segment files, use the node stats API.
fixed_bit_set: Option<String>max_unsafe_auto_id_timestamp: Stringmemory: Option<String>norms_memory_in_bytes: u32points_memory_in_bytes: u32version_map_memory_in_bytes: u32points_memory: Option<String>Implementations
Sourceimpl SegmentsStats
impl SegmentsStats
pub fn new( stored_fields_memory_in_bytes: u32, terms_memory_in_bytes: u32, term_vectors_memory_in_bytes: u32, doc_values_memory_in_bytes: u32, count: u32, index_writer_memory_in_bytes: u32, memory_in_bytes: u32, fixed_bit_set_memory_in_bytes: u32, file_sizes: Value, max_unsafe_auto_id_timestamp: String, norms_memory_in_bytes: u32, points_memory_in_bytes: u32, version_map_memory_in_bytes: u32, ) -> SegmentsStats