SearchSuccess

Type Alias SearchSuccess 

pub type SearchSuccess = SearchResponse;

Aliased Type

pub struct SearchSuccess {
Show 13 fields pub took: u32, pub timed_out: bool, pub terminated_early: Option<bool>, pub scroll_id: Option<String>, pub fields: BTreeMap<String, Value>, pub pit_id: Option<String>, pub num_reduce_phases: Option<u64>, pub max_score: Option<f32>, pub clusters: Option<ClusterStatistics>, pub shards: ShardStatistics, pub hits: HitsMetadata, pub aggregations: BTreeMap<String, AggregationResponse>, pub suggest: BTreeMap<String, Vec<Suggest>>,
}

Fields

took: u32

The time that it took OpenSearch to process the query

timed_out: bool

The search has been cancelled and results are partial

terminated_early: Option<bool>

Indicates if search has been terminated early

scroll_id: Option<String>

Scroll Id

fields: BTreeMap<String, Value>

Dynamically fetched fields

pit_id: Option<String>

Point in time Id

num_reduce_phases: Option<u64>

Number of reduce phases

max_score: Option<f32>

Maximum document score. [None] when documents are implicitly sorted by a field other than _score

clusters: Option<ClusterStatistics>

Number of clusters touched with their states

shards: ShardStatistics

Number of shards touched with their states

hits: HitsMetadata

Search hits

aggregations: BTreeMap<String, AggregationResponse>

Search aggregations

suggest: BTreeMap<String, Vec<Suggest>>

Suggest response