pub struct FieldCapability {
pub aggregatable: bool,
pub non_searchable_indices: Option<Indices>,
pub indices: Option<Indices>,
pub searchable: bool,
pub metadata_field: Option<bool>,
pub type: String,
pub meta: Option<Value>,
pub non_aggregatable_indices: Option<Indices>,
}Fields
aggregatable: boolWhether this field can be aggregated on all indexes.
non_searchable_indices: Option<Indices>A comma-separated list of data streams, indexes, and aliases used to limit the request.
Supports wildcards (*).
To target all data streams and indexes, omit this parameter or use * or _all.
indices: Option<Indices>A comma-separated list of data streams, indexes, and aliases used to limit the request.
Supports wildcards (*).
To target all data streams and indexes, omit this parameter or use * or _all.
searchable: boolWhether this field is indexed for search on all indexes.
metadata_field: Option<bool>Whether this field is registered as a metadata field.
type: Stringmeta: Option<Value>non_aggregatable_indices: Option<Indices>A comma-separated list of data streams, indexes, and aliases used to limit the request.
Supports wildcards (*).
To target all data streams and indexes, omit this parameter or use * or _all.
Implementations