pub struct Source {
pub slice: Option<SlicedScroll>,
pub remote: Option<RemoteSource>,
pub sort: Option<Sort>,
pub source: Option<Fields>,
pub index: Indices,
pub query: Option<Query>,
pub size: Option<u32>,
}Fields
slice: Option<SlicedScroll>remote: Option<RemoteSource>sort: Option<Sort>source: Option<Fields>index: IndicesA comma-separated list of data streams, indexes, and aliases used to limit the request.
Supports wildcards (*).
To target all data streams and indexes, omit this parameter or use * or _all.
query: Option<Query>size: Option<u32>The number of documents to index per batch.
Use the size setting when indexing from a remote cluster. This ensures that batches fit in the on-heap buffer. The buffer defaults to a maximum size of 100MB.
Implementations