pub struct NestedIdentity {
pub offset: u32,
pub nested: Option<Box<NestedIdentity>>,
pub field: String,
}Fields
offset: u32nested: Option<Box<NestedIdentity>>field: StringThe path to a field or an array of paths. Some APIs support wildcards in the path, which allows you to select multiple fields.
Implementations
Sourceimpl NestedIdentity
impl NestedIdentity
pub fn new(offset: u32, field: String) -> NestedIdentity