pub struct RescoreQuery {
pub query_weight: Option<f64>,
pub score_mode: Option<String>,
pub rescore_query: Query,
pub rescore_query_weight: Option<f64>,
}Fields
query_weight: Option<f64>The relative importance of the original query as compared to the rescore query.
score_mode: Option<String>rescore_query: Queryrescore_query_weight: Option<f64>The relative importance of the rescore query as compared to the original query.
Implementations
Sourceimpl RescoreQuery
impl RescoreQuery
pub fn new(rescore_query: Query) -> RescoreQuery