pub struct Alias {
pub routing: Option<String>,
pub search_routing: Option<String>,
pub index_routing: Option<String>,
pub filter: Option<Query>,
pub is_hidden: Option<bool>,
pub is_write_index: Option<bool>,
}Fields
routing: Option<String>search_routing: Option<String>index_routing: Option<String>filter: Option<Query>If true, the alias is hidden.
All indexes for the alias must have the same is_hidden value.
is_write_index: Option<bool>If true, the index is the write index for the alias.
Implementations