DataStream

Struct DataStream 

pub struct DataStream {
Show 14 fields pub ilm_policy: Option<String>, pub indices: Vec<DataStreamIndex>, pub hidden: Option<bool>, pub prefer_ilm: Option<bool>, pub generation: u32, pub status: HealthStatus, pub meta: Option<Metadata>, pub system: Option<bool>, pub template: String, pub timestamp_field: DataStreamTimestampField, pub replicated: Option<bool>, pub name: String, pub next_generation_managed_by: Option<String>, pub allow_custom_routing: Option<bool>,
}

Fields

ilm_policy: Option<String>indices: Vec<DataStreamIndex>

Array of objects containing information about the data stream’s backing indexes. The last item in this array contains information about the stream’s current write index.

hidden: Option<bool>

If true, the data stream is hidden.

prefer_ilm: Option<bool>

Indicates if ILM should take precedence over DSL in case both are configured to managed this data stream.

generation: u32

Current generation for the data stream. This number acts as a cumulative count of the stream’s rollovers, starting at 1.

status: HealthStatusmeta: Option<Metadata>system: Option<bool>

If true, the data stream is created and managed by an OpenSearch stack component and cannot be modified through normal user interaction.

template: Stringtimestamp_field: DataStreamTimestampFieldreplicated: Option<bool>

If true, the data stream is created and managed by cross-cluster replication and the local cluster can not write into this data stream or change its mappings.

name: Stringnext_generation_managed_by: Option<String>allow_custom_routing: Option<bool>

If true, the data stream allows custom routing on write request.

Implementations

Source

impl DataStream

pub fn new( indices: Vec<DataStreamIndex>, generation: u32, status: HealthStatus, template: String, timestamp_field: DataStreamTimestampField, name: String, ) -> DataStream