pub struct DataStreamTimestampField {
pub name: String,
}Fields
name: StringThe path to a field or an array of paths. Some APIs support wildcards in the path, which allows you to select multiple fields.
Implementations
Sourceimpl DataStreamTimestampField
impl DataStreamTimestampField
pub fn new(name: String) -> DataStreamTimestampField