IndexSettingsQueryString

Struct IndexSettingsQueryString 

pub struct IndexSettingsQueryString {
    pub lenient: Option<StringifiedBoolean>,
}

Fields

lenient: Option<StringifiedBoolean>

Certain APIs may return values, including numbers such as epoch timestamps, as strings. This setting captures this behavior while keeping the semantics of the field type.

Depending on the target language, code generators can keep the union or remove it and leniently parse strings to the target type.

Implementations