pub struct PutMapping {
pub properties: Option<Value>,
pub field_names: Option<FieldNamesField>,
pub source: Option<SourceField>,
pub dynamic_date_formats: Option<Vec<String>>,
pub date_detection: Option<bool>,
pub routing: Option<RoutingField>,
pub meta: Option<Metadata>,
pub dynamic: Option<String>,
pub numeric_detection: Option<bool>,
}Expand description
PutMapping The mapping definition
Fields
properties: Option<Value>Mapping for a field. For new fields, this mapping can include:
- Field name
- Field data type
- Mapping parameters
field_names: Option<FieldNamesField>source: Option<SourceField>dynamic_date_formats: Option<Vec<String>>If date detection is enabled then new string fields are checked
against dynamic_date_formats and if the value matches then
a new date field is added instead of string.
date_detection: Option<bool>Controls whether dynamic date detection is enabled.
routing: Option<RoutingField>meta: Option<Metadata>dynamic: Option<String>numeric_detection: Option<bool>Automatically map strings into numeric data types for all fields.
Implementations
Sourceimpl PutMapping
impl PutMapping
Sourcepub fn new() -> PutMapping
pub fn new() -> PutMapping
The mapping definition