pub struct SimulateTemplate {
pub composed_of: Option<Vec<String>>,
pub meta: Option<Metadata>,
pub priority: Option<u32>,
pub version: Option<u32>,
pub allow_auto_create: Option<bool>,
pub index_patterns: Names,
pub template: Option<IndexTemplateSummary>,
pub data_stream: Option<IndexTemplateDataStreamConfiguration>,
}Expand description
SimulateTemplate New index template definition to be simulated, if no index template name is specified.
Fields
composed_of: Option<Vec<String>>An ordered list of component template names. Component templates are merged in the order specified, meaning that the last component template specified has the highest precedence.
meta: Option<Metadata>priority: Option<u32>Priority to determine index template precedence when a new data stream or index is created. The index template with the highest priority is chosen. If no priority is specified the template is treated as though it is of priority 0 (lowest priority). This number is not automatically generated by OpenSearch.
version: Option<u32>allow_auto_create: Option<bool>index_patterns: NamesA comma-separated list of aliases to retrieve. Supports wildcards (*). To retrieve all aliases, omit this parameter or use * or _all.
template: Option<IndexTemplateSummary>data_stream: Option<IndexTemplateDataStreamConfiguration>Implementations
Sourceimpl SimulateTemplate
impl SimulateTemplate
Sourcepub fn new(index_patterns: Names) -> SimulateTemplate
pub fn new(index_patterns: Names) -> SimulateTemplate
New index template definition to be simulated, if no index template name is specified.