pub struct PutAlias {
pub index: Option<String>,
pub index_routing: Option<String>,
pub routing: Option<String>,
pub filter: Option<Query>,
pub is_write_index: Option<bool>,
pub search_routing: Option<String>,
pub alias: Option<String>,
}Expand description
PutAlias
The settings for the alias, such as routing or filter
Fields
index: Option<String>index_routing: Option<String>routing: Option<String>filter: Option<Query>is_write_index: Option<bool>If true, sets the write index or data stream for the alias.
If an alias points to multiple indexes or data streams and is_write_index isn’t set, the alias rejects write requests.
If an index alias points to one index and is_write_index isn’t set, the index automatically acts as the write index.
Data stream aliases don’t automatically set a write data stream, even if the alias points to one data stream.
search_routing: Option<String>alias: Option<String>Implementations