pub struct DocumentSimulation {
pub index: String,
pub version: Option<StringifiedVersionNumber>,
pub routing: Option<String>,
pub version_type: Option<String>,
pub ingest: Ingest,
pub id: String,
pub source: Value,
}Fields
index: Stringversion: Option<StringifiedVersionNumber>Certain APIs may return values, including numbers such as epoch timestamps, as strings. This setting captures this behavior while keeping the semantics of the field type.
Depending on the target language, code generators can keep the union or remove it and leniently parse strings to the target type.
routing: Option<String>Value used to send the document to a specific primary shard.
version_type: Option<String>ingest: Ingestid: Stringsource: ValueJSON body for the document.
Implementations