pub struct Ingest {
pub timestamp: DateTime,
pub pipeline: Option<String>,
}Fields
timestamp: DateTimeA date and time, either as a string whose format depends on the context (defaulting to ISO_8601) or the number of milliseconds since the epoch. OpenSearch accepts both as an input but will generally output a string. representation.
pipeline: Option<String>Implementations