pub struct Nested {
pub score_mode: Option<String>,
pub ignore_unmapped: Option<bool>,
pub boost: Option<f64>,
pub path: Option<String>,
pub query: Option<Query>,
}Expand description
Nested The nested filter.
Fields
score_mode: Option<String>The score mode.
ignore_unmapped: Option<bool>Whether to ignore unmapped fields.
boost: Option<f64>Adjust the relevance score of a match.
path: Option<String>The path to a field or an array of paths. Some APIs support wildcards in the path, which allows you to select multiple fields.
query: Option<Query>The query.
Implementations