AllocationExplainRequestBodyJson

Struct AllocationExplainRequestBodyJson 

pub struct AllocationExplainRequestBodyJson {
    pub primary: Option<bool>,
    pub current_node: Option<String>,
    pub shard: Option<u32>,
    pub index: Option<String>,
}
AllocationExplainRequestBodyJson The index, shard, and primary flag for which to generate an explanation. Leave this empty to generate an explanation for the first unassigned shard.

Fields

primary: Option<bool>

When true, returns a routing explanation for the primary shard based on the node ID.

current_node: Option<String>

Specifies the node ID or the name of the node to only explain a shard that is currently located on the specified node.

shard: Option<u32>

Specifies the ID of the shard that you would like an explanation for.

index: Option<String>

Implementations

Source

impl AllocationExplainRequestBodyJson

pub fn new() -> AllocationExplainRequestBodyJson

The index, shard, and primary flag for which to generate an explanation. Leave this empty to generate an explanation for the first unassigned shard.