BulkByScrollTaskStatusValue

Struct BulkByScrollTaskStatusValue 

pub struct BulkByScrollTaskStatusValue {
Show 16 fields pub throttled_until_millis: String, pub requests_per_second: f64, pub version_conflicts: u32, pub noops: u32, pub throttled_millis: String, pub slices: Option<Vec<BulkByScrollTaskStatusOrException>>, pub created: Option<u32>, pub canceled: Option<String>, pub throttled_until: Option<String>, pub batches: u32, pub slice_id: Option<u32>, pub total: u32, pub retries: Retries, pub deleted: u32, pub throttled: Option<String>, pub updated: Option<u32>,
}

Fields

throttled_until_millis: Stringrequests_per_second: f64

The number of requests per second effectively executed during the reindex operation.

version_conflicts: u32

The number of version conflicts encountered by the reindex operation.

noops: u32

The number of documents that were ignored.

throttled_millis: Stringslices: Option<Vec<BulkByScrollTaskStatusOrException>>created: Option<u32>

The number of documents that were successfully created.

canceled: Option<String>throttled_until: Option<String>

A duration. Units can be nanos, micros, ms (milliseconds), s (seconds), m (minutes), h (hours) and d (days). Also accepts “0” without a unit and “-1” to indicate an unspecified value.

batches: u32

The number of scroll responses pulled back by the reindex operation.

slice_id: Option<u32>total: u32

The number of documents that were successfully processed.

retries: Retriesdeleted: u32

The number of documents that were successfully deleted.

throttled: Option<String>

A duration. Units can be nanos, micros, ms (milliseconds), s (seconds), m (minutes), h (hours) and d (days). Also accepts “0” without a unit and “-1” to indicate an unspecified value.

updated: Option<u32>

The number of documents that were successfully updated after the reindex operation.

Implementations

Source

impl BulkByScrollTaskStatusValue

pub fn new( throttled_until_millis: String, requests_per_second: f64, version_conflicts: u32, noops: u32, throttled_millis: String, batches: u32, total: u32, retries: Retries, deleted: u32, ) -> BulkByScrollTaskStatusValue